@@ -34,10 +34,9 @@
    ;; aliases
    ["-R" "--resolve-aliases ALIASES" "Concatenated resolve-deps alias names" :parse-fn parse/parse-kws]
    ["-C" "--makecp-aliases ALIASES" "Concatenated make-classpath alias names" :parse-fn parse/parse-kws]
-   ["-J" "--jvmopt-aliases ALIASES" "Concatenated jvm option alias names" :parse-fn parse/parse-kws]
+   ["-A" "--repl-aliases ALIASES" "Concatenated repl alias names" :parse-fn parse/parse-kws]
    ["-M" "--main-aliases ALIASES" "Concatenated main option alias names" :parse-fn parse/parse-kws]
-   ["-T" "--tool-aliases ALIASES" "Concatenated tool alias names" :parse-fn parse/parse-kws]
-   ["-A" "--aliases ALIASES" "Concatenated generic alias names" :parse-fn parse/parse-kws]
+   ["-X" "--exec-aliases ALIASES" "Concatenated exec alias names" :parse-fn parse/parse-kws]
    ;; options
    [nil "--trace" "Emit trace log to trace.edn"]
    [nil "--threads THREADS" "Threads for concurrent downloads"]])
@@ -68,29 +67,37 @@
      ;; and any other qualified keys from top level merged deps
     }"
   [{:keys [install-deps user-deps project-deps config-data ;; all deps.edn maps
-           resolve-aliases makecp-aliases jvmopt-aliases main-aliases tool-aliases aliases
+           resolve-aliases makecp-aliases main-aliases exec-aliases repl-aliases
            skip-cp threads trace] :as opts}]
-  (let [;; tool use - replace :deps / :paths if needed
+  (when (and main-aliases exec-aliases)
+    (throw (ex-info "-M and -X cannot be used at the same time" {})))
+  (let [;; tool use - :deps/:paths/:replace-deps/:replace-paths in project if needed
         tool-args (deps/combine-aliases
                     (deps/merge-edns [install-deps user-deps project-deps config-data]) ;; merge just to get all aliases
-                    (concat tool-aliases aliases))
+                    (concat main-aliases exec-aliases repl-aliases))
         project-deps (deps/tool project-deps tool-args)
 
         ;; calc basis
         merge-edn (deps/merge-edns [install-deps user-deps project-deps config-data])
-        _ (check-aliases merge-edn (concat resolve-aliases makecp-aliases jvmopt-aliases main-aliases tool-aliases aliases))
-        resolve-args (cond-> (deps/combine-aliases merge-edn (concat resolve-aliases aliases))
+        combined-exec-aliases (concat main-aliases exec-aliases repl-aliases)
+        _ (check-aliases merge-edn (concat resolve-aliases makecp-aliases combined-exec-aliases))
+        resolve-argmap (deps/combine-aliases merge-edn (concat resolve-aliases combined-exec-aliases))
+        resolve-args (cond-> resolve-argmap
                        threads (assoc :threads (Long/parseLong threads))
                        trace (assoc :trace trace))
-        cp-args (deps/combine-aliases merge-edn (concat makecp-aliases aliases))
-        basis (when-not skip-cp (deps/calc-basis merge-edn {:resolve-args resolve-args :classpath-args cp-args}))
-        trace-log (-> basis :libs meta :trace)
+        basis (when-not skip-cp (deps/calc-basis merge-edn {:resolve-args resolve-args
+                                                            :classpath-args (deps/combine-aliases merge-edn
+                                                                              (concat makecp-aliases combined-exec-aliases))}))
 
         ;; handle jvm and main opts
-        jvm (seq (get (deps/combine-aliases merge-edn (concat jvmopt-aliases aliases)) :jvm-opts))
-        main (seq (get (deps/combine-aliases merge-edn (concat main-aliases aliases)) :main-opts))]
+        exec-argmap (deps/combine-aliases merge-edn combined-exec-aliases)
+        jvm (seq (get exec-argmap :jvm-opts))
+        main (seq (get exec-argmap :main-opts))]
+    (when (and main repl-aliases)
+      (io/printerrln "WARNING: Use of :main-opts with -A is deprecated. Use -M instead."))
     (cond-> basis
       jvm (assoc :jvm jvm)
+      ;; FUTURE: narrow this to (and main main-aliases)
       main (assoc :main main))))
 
 (defn read-deps
@@ -106,13 +113,13 @@
   (let [opts' (merge opts {:install-deps (deps/root-deps)
                            :user-deps (read-deps config-user)
                            :project-deps (read-deps config-project)})
-        {:keys [libs classpath jvm main] :as basis} (run-core opts')
+        {:keys [libs classpath-roots jvm main] :as basis} (run-core opts')
         trace (-> libs meta :trace)]
     (when trace
       (spit "trace.edn" (binding [*print-namespace-maps* false] (with-out-str (clojure.pprint/pprint trace)))))
     (when-not skip-cp
       (io/write-file libs-file (binding [*print-namespace-maps* false] (pr-str libs)))
-      (io/write-file cp-file (-> classpath keys deps/join-classpath)))
+      (io/write-file cp-file (-> classpath-roots deps/join-classpath)))
     (io/write-file basis-file (binding [*print-namespace-maps* false] (pr-str basis)))
     (if jvm
       (io/write-file jvm-file (str/join " " jvm))
@@ -139,10 +146,9 @@
     --basis-file=path - basis file to write
     -Rresolve-aliases - concatenated resolve-deps alias names
     -Cmakecp-aliases - concatenated make-classpath alias names
-    -Jjvmopt-aliases - concatenated jvm-opt alias names
     -Mmain-aliases - concatenated main-opt alias names
-    -Ttool-aliases - concatenated tool alias names
-    -Aaliases - concatenated generic alias names
+    -Aaliases - concatenated repl alias names
+    -Xaliases - concatenated exec alias names
 
   Resolves the dependencies and updates the lib, classpath, etc files.
   The libs file is at <cachedir>/<hash>.libs
